@@ -13,15 +13,14 @@ class SerfHandler(object):
             self.event = os.environ['SERF_EVENT'].replace('-', '_')
 
     def log(self, message):
-        print message
-
-    def run(self, command):
-        pass
+        print(message)
 
 
 class SerfHandlerProxy(SerfHandler):
 
-    handlers = {}
+    def __init__(self):
+        super(SerfHandlerProxy, self).__init__()
+        self.handlers = {}
 
     def register(self, role, handler):
         self.handlers[role] = handler
@@ -43,13 +42,3 @@ class SerfHandlerProxy(SerfHandler):
                 getattr(klass, self.event)()
             except AttributeError:
                 self.log("event not implemented by class")
-            except TypeError:
-                self.log("no handler for role")
-
-
-if __name__ == '__main__':
-    handler = SerfHandlerProxy()
-    handler.register('lb', LbHandler())
-    handler.register('web', WebHandler())
-    handler.register('default', WebHandler())
-    handler.run()
